#! /usr/bin/env python
# -*- coding: utf-8 -*-
# vim:fenc=utf-8
#
# Copyright © 2018 zenbook <zenbook@zenbook-XPS>
#
# Distributed under terms of the MIT license.

"""

"""

from pymysql.cursors import DictCursor
from .core import TableDict

dict_type = TableDict(None)


class KaniCursor(DictCursor):
    dict_type = dict_type
    table_dict_list = {}
    # You can override this to use OrderedDict or other dict-like types.

    def setup_table_dict_list(self, table_dict_list):
        self.table_dict_list = table_dict_list

    def set_table_dict(self, table_name, table_dict):
        self.table_dict_list[table_name] = table_dict

    def _conv_row(self, row):
        if row is None:
            return None
        table_name = self._result.fields[0].table_name
        if table_name in self.table_dict_list:
            table_dict = self.table_dict_list[table_name]
            return table_dict(zip(self._fields, row))
        else:
            result = self.dict_type(zip(self._fields, row))
            result._setattr('_table_name', table_name)
            return result



#! /usr/bin/env python
# -*- coding: utf-8 -*-
# vim:fenc=utf-8
#
# Copyright © 2018 zenbook <zenbook@zenbook-XPS>
#
# Distributed under terms of the MIT license.

"""

"""


def count(column):
    return '#COUNT(`%s`)' % (column)


def sum(column):
    return '#SUM(`%s`)' % (column)


def desc(column):
    return '#`%s` DESC' % (column)


def escape(query):
    return '#%s' % (query)



#!/usr/bin/python
# -*-coding: utf-8 -*-

from setuptools import setup, find_packages
from os import path

here = path.abspath(path.dirname(__file__))

with open('README.md') as f:
    long_description = f.read()

setup(name='kanimysql',
      version='0.1.2',
      description='A MySQL class for more convenient database manipulations with Python dictionary.',
      long_description=long_description,
      author='Kirin Fx',
      author_email='ono.kirin@gmail.com',
      license='MIT',
      packages=find_packages(),
      classifiers=[
          'Development Status :: 5 - Production/Stable',
          'Intended Audience :: Developers',
          'Topic :: Software Development :: Build Tools',
          'License :: OSI Approved :: MIT License',
          'Programming Language :: Python :: 2.6',
          'Programming Language :: Python :: 2.7',
          'Programming Language :: Python :: 3.1',
          'Programming Language :: Python :: 3.2',
          'Programming Language :: Python :: 3.3',
          'Programming Language :: Python :: 3.4',
          'Programming Language :: Python :: 3.5',
          'Programming Language :: Python :: 3.6',
      ],
      keywords='python mysql class',
      url='https://github.com/fx-kirin/kanimysql',
      install_requires=["PyMySQL>=0.7", "python-string-utils", "interval_decorator", "attrdict", "funcy"],
      )
